@@ -4,11 +4,11 @@ __all__ = [
     "AsFrame",
     "AsSeries",
     "Attr",
-    "Column",
     "Data",
     "Index",
-    "Other",
+    "Multiple",
     "Spec",
+    "Tag",
     "asdataframe",
     "asframe",
     "aspandas",
@@ -16,7 +16,7 @@ __all__ = [
     "core",
     "extras",
 ]
-__version__ = "0.11.0"
+__version__ = "1.0.0"
 
 
 # submodules
@@ -24,7 +24,9 @@ from . import core
 from . import extras
 from .core.api import *
 from .core.specs import *
+from .core.tagging import *
 from .core.typing import *
+from .extras.hints import *
 from .extras.new import *
 
 
